ig_material_localization_delegate library

Constants

igDateSymbols → const Map<String, Object?>
A custom set of date symbols for the yr locale.
igLocaleDatePatterns → const Map<String, String>
A custom set of date patterns for the yr locale.