reorderItemUp property
The semantics label used for SliverReorderableList to reorder an item in the list one space up the list.
Implementation
@override
// TODO: implement reorderItemUp
String get reorderItemUp => r'Bulie elu';
The semantics label used for SliverReorderableList to reorder an item in the list one space up the list.
@override
// TODO: implement reorderItemUp
String get reorderItemUp => r'Bulie elu';